@@ -1,14 +1,14 @@
 __doc__ = """
 This program requires python 3.6 or higher.
 
-Print(functionName.__doc__) to see the 
+print(functionName.__doc__) to see the
 
 documentation for the function or usage.
 
 Send enquiries to osita@protein-science.com
 """
 """
-This dictionary holds residue names, complete 
+This dictionary holds residue names, complete
 atoms and force-field parameters for each atom.
 Each residue may be in C-terminal, hence OXT is added
 For the child dictionary value:
@@ -17,7 +17,7 @@ index 1 = sigma(nm)
 index 2 = epsilon(kJ/mol)
 
 """
-param={     
+param={
      'ASP' :{'N':[-0.558201, 0.3250001, 0.711280],
            'CA':[0.007225, 0.339967, 0.457730],
            'C':[0.443199, 0.339967, 0.359824],
@@ -55,14 +55,14 @@ param={
 
       'VAL' :{'N':[-0.450087, 0.3250001, 0.711280],
             'CA':[-0.051858, 0.339967, 0.457730],
-            'C' :[0.447359, 0.339967, 0.359824], 
+            'C' :[0.447359, 0.339967, 0.359824],
             'O':[-0.404629, 0.295992, 0.878640],
             'CB':[0.395217, 0.339967, 0.457730],
             'CG1':[-0.090132, 0.339967, 0.457730],
             'CG2' :[-0.090132, 0.339967, 0.457730],
             'OXT':[-0.501445, 0.295992, 0.878640]},
 
-      'ALA' :{'N':[-0.404773, 0.3250001, 0.711280], 
+      'ALA' :{'N':[-0.404773, 0.3250001, 0.711280],
             'CA':[-0.027733, 0.339967, 0.457730],
             'C' :[0.570224, 0.339967, 0.359824],
             'O':[-0.555129, 0.295992, 0.878640],
@@ -77,7 +77,7 @@ param={
             'CG1':[0.022230, 0.339967, 0.457730],
             'CG2':[-0.129989, 0.339967, 0.457730],
             'CD1':[-0.101251, 0.339967, 0.457730],
-            'OXT':[-0.501445, 0.295992, 0.878640]}, 
+            'OXT':[-0.501445, 0.295992, 0.878640]},
 
       'LEU' :{'N':[-0.355153, 0.3250001, 0.711280],
             'CA':[-0.101497, 0.339967, 0.457730],
@@ -89,11 +89,11 @@ param={
             'CD2':[-0.123036, 0.339967, 0.457730],
             'OXT':[-0.501445, 0.295992, 0.878640]},
 
-      'THR' :{'N':[-0.245382, 0.3250001, 0.711280], 
+      'THR' :{'N':[-0.245382, 0.3250001, 0.711280],
             'CA':[-0.271249, 0.339967, 0.457730],
-            'C':[0.559878, 0.339967, 0.359824], 
+            'C':[0.559878, 0.339967, 0.359824],
             'O':[-0.552020, 0.295992, 0.878640],
-            'CB':[0.237868, 0.339967, 0.457730], 
+            'CB':[0.237868, 0.339967, 0.457730],
             'CG2':[-0.176489, 0.339967, 0.457730],
             'OG1':[-0.601931, 0.306647, 0.880314],
             'OXT':[-0.501445, 0.295992, 0.878640]},
@@ -102,9 +102,9 @@ param={
             'CA':[-0.020082, 0.339967, 0.457730],
             'C':[0.584129, 0.339967, 0.359824],
             'O':[-0.494730, 0.295992, 0.878640],
-            'CB':[-0.098364, 0.339967, 0.457730], 
+            'CB':[-0.098364, 0.339967, 0.457730],
             'CG':[-0.099797, 0.339967, 0.359824],
-            'CD1':[-0.174053, 0.339967, 0.359824], 
+            'CD1':[-0.174053, 0.339967, 0.359824],
             'CD2':[0.089641, 0.339967, 0.359824],
             'CE2':[0.141523, 0.339967, 0.359824],
             'CE3':[-0.153992, 0.339967, 0.359824],
@@ -129,7 +129,7 @@ param={
 
       'ASN' :{'N':[-0.430106, 0.3250001, 0.711280],
             'CA':[0.044609, 0.339967, 0.457730],
-            'C':[0.617141, 0.339967, 0.359824], 
+            'C':[0.617141, 0.339967, 0.359824],
             'O':[-0.523909, 0.295992, 0.878640],
             'CB':[-0.093650, 0.339967, 0.457730],
             'CG':[0.583519, 0.339967, 0.359824],
@@ -162,7 +162,7 @@ param={
             'O':[-0.592528, 0.295992, 0.878640],
             'CB':[0.074772, 0.339967, 0.457730],
             'CG':[-0.033909, 0.339967, 0.457730],
-            'CD':[0.765188, 0.339967, 0.359824], 
+            'CD':[0.765188, 0.339967, 0.359824],
             'OE1':[-0.824035, 0.295992, 0.878640],
             'OE2':[-0.824035, 0.295992, 0.878640],
             'OXT':[-0.501445, 0.295992, 0.878640]},
@@ -194,7 +194,7 @@ param={
 
       'PRO' :{'N':[-0.088116, 0.3250001, 0.711280],
             'CA':[-0.034577, 0.339967, 0.457730],
-            'C':[0.333720, 0.339967, 0.359824], 
+            'C':[0.333720, 0.339967, 0.359824],
             'O':[-0.434559, 0.295992, 0.878640],
             'CB':[-0.003351, 0.339967, 0.457730],
             'CG':[0.013059, 0.339967, 0.457730],
