@@ -1,7 +1,7 @@
 __doc__ = """
 This program requires python 3.6 or higher.
 
-Print(functionName.__doc__) to see the
+print(functionName.__doc__) to see the
 
 documentation for the function or usage.
 
@@ -18,7 +18,7 @@ def arginine_h(ires,i="",nextres=None):
     Annotation is provided in detail here only  b/c all the
     functions are essentially the same, that is, they take
     similar arguments except SER, THR, TYR and free CYS that have class6 H-atoms
-    to be optimized with a potential energy function. The last 4 functions
+    to be optimized with a potential energy function. The last 6 functions
     are different from these 20 and annotations are provided
 
     This function adds missing hydrogen atoms of the ARG residue.
@@ -830,7 +830,7 @@ def notDisulfide(ires,i,resNo,atoms2,atmpos2,resNo2,resseq2,nextres=None):
         nextres_N  = nextres[2][0]
         H              =  LinearAlgebra.class5(nextres_CA,nextres_N,pos_C,1.01)
         HA             =  LinearAlgebra.class3(pos_CB,pos_N,pos_CA)
-        HG             =  LinearAlgebra.Cys_HG(pos_SG, pos_CB, pos_CA)
+        HG             =  LinearAlgebra.cys_HG(pos_SG, pos_CB, pos_CA)
         HB1,HB2        =  LinearAlgebra.class2(pos_CA,pos_SG,pos_CB)
         di             =  LinearAlgebra.calcTorsionAngle(pos_CA,pos_CB,pos_SG,HG)
         xyz            =  [pos_CA,pos_CB,pos_SG,HG,1.34,di,0.19,0.11,0.07]
@@ -844,7 +844,7 @@ def notDisulfide(ires,i,resNo,atoms2,atmpos2,resNo2,resseq2,nextres=None):
 
     else:
         HA             =  LinearAlgebra.class3(pos_CB,pos_N,pos_CA)
-        HG             =  LinearAlgebra.Cys_HG(pos_SG, pos_CB, pos_CA)
+        HG             =  LinearAlgebra.cys_HG(pos_SG, pos_CB, pos_CA)
         HB1,HB2        =  LinearAlgebra.class2(pos_CA,pos_SG,pos_CB)
         di             =  LinearAlgebra.calcTorsionAngle(pos_CA,pos_CB,pos_SG,HG)
         xyz            =  [pos_CA,pos_CB,pos_SG,HG,1.34,di,0.19,0.11,0.07]
@@ -876,7 +876,7 @@ def threonine_h(ires,i,resNo,atoms2,atmpos2,resNo2,resseq2,nextres=None):
         nextres_N  = nextres[2][0]
         H              =  LinearAlgebra.class5(nextres_CA,nextres_N,pos_C,1.01)
         HA             =  LinearAlgebra.class3(pos_CB,pos_N,pos_CA)
-        HG1            =  LinearAlgebra.Thr_HG1(pos_OG1,pos_CB,pos_CG2)
+        HG1            =  LinearAlgebra.thr_HG1(pos_OG1,pos_CB,pos_CG2)
         HB             =  LinearAlgebra.class3(pos_CA,pos_OG1,pos_CB)
         HG12           =  LinearAlgebra.calcCoordinate(pos_OG1,pos_CB,pos_CG2,1.09,60.5,109.4)
         HG22           =  LinearAlgebra.calcCoordinate(pos_OG1,pos_CB,pos_CG2,1.09,-179.5,109.5)
@@ -893,7 +893,7 @@ def threonine_h(ires,i,resNo,atoms2,atmpos2,resNo2,resseq2,nextres=None):
 
 
     HA             =  LinearAlgebra.class3(pos_CB,pos_N,pos_CA)
-    HG1            =  LinearAlgebra.Thr_HG1(pos_OG1,pos_CB,pos_CG2)
+    HG1            =  LinearAlgebra.thr_HG1(pos_OG1,pos_CB,pos_CG2)
     HB             =  LinearAlgebra.class3(pos_CA,pos_OG1,pos_CB)
     HG12           =  LinearAlgebra.calcCoordinate(pos_OG1,pos_CB,pos_CG2,1.09,60.5,109.4)
     HG22           =  LinearAlgebra.calcCoordinate(pos_OG1,pos_CB,pos_CG2,1.09,-179.5,109.5)
@@ -984,7 +984,7 @@ def tyrosine_h(ires,i,resNo,atoms2,atmpos2,resNo2,resseq2,nextres=None):
         HD2            =  LinearAlgebra.class5(pos_CE2,pos_CD2,pos_CG,1.08)
         HE1            =  LinearAlgebra.class5(pos_CZ,pos_CE1,pos_CD1,1.08)
         HE2            =  LinearAlgebra.class5(pos_CZ,pos_CE2,pos_CD2,1.08)
-        HH             =  LinearAlgebra.Tyr_HH(pos_OH,pos_CZ,pos_CE2)
+        HH             =  LinearAlgebra.tyr_HH(pos_OH,pos_CZ,pos_CE2)
         di             =  LinearAlgebra.calcTorsionAngle(pos_CE2,pos_CZ,pos_OH,HH)
         xyz            =  [pos_CE2,pos_CZ,pos_OH,HH,0.96,di,0.37,0.0,0.0]
         HH             =  PotentialEnergy.optmizeH(resNo,atoms2,atmpos2,resNo2,resseq2,xyz)
@@ -1001,7 +1001,7 @@ def tyrosine_h(ires,i,resNo,atoms2,atmpos2,resNo2,resseq2,nextres=None):
     HD2            =  LinearAlgebra.class5(pos_CE2,pos_CD2,pos_CG,1.08)
     HE1            =  LinearAlgebra.class5(pos_CZ,pos_CE1,pos_CD1,1.08)
     HE2            =  LinearAlgebra.class5(pos_CZ,pos_CE2,pos_CD2,1.08)
-    HH             =  LinearAlgebra.Tyr_HH(pos_OH,pos_CZ,pos_CE2)
+    HH             =  LinearAlgebra.tyr_HH(pos_OH,pos_CZ,pos_CE2)
     di             =  LinearAlgebra.calcTorsionAngle(pos_CE2,pos_CZ,pos_OH,HH)
     xyz            =  [pos_CE2,pos_CZ,pos_OH,HH,0.96,di,0.37,0.0,0.0]
     HH             =  PotentialEnergy.optmizeH(resNo,atoms2,atmpos2,resNo2,resseq2,xyz)
