@@ -1,7 +1,7 @@
 __doc__ = """
 This program requires python 3.6 or higher.
 
-Print(functionName.__doc__) to see the 
+print(functionName.__doc__) to see the 
 
 documentation for the function or usage.
 
@@ -108,7 +108,7 @@ def calcCoordinate(a,b,c,bond_len,di_angle,theta):
     pos_BL = ((pos_ini-c)*(bond_len/np.linalg.norm(pos_ini-c)))+c
     return pos_BL.tolist()
 
-def optmize(pos_CA,pos_CB,pos_OG1,pos_HG1,BL,di):
+def _optmize(pos_CA,pos_CB,pos_OG1,pos_HG1,BL,di):
     """
     This function rotates class6 H-atoms through 360 deg 
     
@@ -157,7 +157,7 @@ def optmizeH(num,atom,atmpos,resNo,resn,data):
     A list: the coordinate corresponding to the lowest potential energy 
     """
     total_ener = []
-    opt_h = optmize(data[0],data[1],data[2],data[3],data[4],data[5])
+    opt_h = _optmize(data[0],data[1],data[2],data[3],data[4],data[5])
     for z in range(len(resNo)):
         if resNo[z] ==num:
             _pos  = [pos for i, pos in enumerate(atmpos) if i != z]
